- [x] Suppress colors in links
- [x] Les consignes ne sont pas miss en forme (gras de nom et prénom)
- [x] Gestion de la langue
- [x] Author
- [x] Support pour les fill-in-the-blank
- [x] Ajouter espace sur première page pour nom/prénom prendre exemple sur...
- [x] Support for multiple answers
  [ ] Résoudre problème callout solution
- Fin du travail écrit "Fin" avec une capitale
- Support for boxes
- Générer documentation du package
- Ajouter CI
- Publier sur PyPI


# Drawbox

Draw a sheep in the box. Box parameter will draw a box or the solution. You can configure the box size either by giving the height: `box=5cm` or both width and height `box=50x40` this time in mm.

!!! solution { box=40 }

    ![sheep]{sheep.drawio}

# Configuration
